@@ -19,6 +19,7 @@ def main():
     parser = argparse.ArgumentParser()
     parser.add_argument("plot", help="subcommand")
     parser.add_argument("-d", "--delimiter", help="delimiter", default="\t")
+    parser.add_argument("-H", "--header", nargs='?', help="input has a header row", type=int, const=0)
     parser.add_argument("--format", help="outout image file format", default="svg")
     parser.add_argument("--show", help="call plt.show()", action="store_true")
     parser.add_argument("--debug", help="print seaborn args", action="store_true")
@@ -28,8 +29,16 @@ def main():
 
     if args.debug:
         print(seaborn_args)
+        print(args)
+
+    # seaborn -H  : {header = 0}
+    # seaborn -H2 : {header = 2}
+    # seaborn     : {header = None}
+    df = pd.read_table(sys.stdin, sep=args.delimiter, header=args.header)
+
+    # seaborn --x 1 --y 2
+    df.columns = df.columns.astype(str)
 
-    df = pd.read_csv(sys.stdin, sep=args.delimiter)
     getattr(seaborn, args.plot)(data=df, **seaborn_args)
 
     if args.show:
